import subprocess
import sys
import os
import argparse
from zuper_commons.logs import setup_logging
from . import logger
from .commons import get_dir_info
import traceback

__all__ = ['aido_check_not_dirty_main']

def aido_check_not_dirty_main(args=None):
    setup_logging()

    parser = argparse.ArgumentParser()
    parser.add_argument('--directory', '-d',  default=".")
    parser.add_argument('cmd', nargs='*')
    parsed = parser.parse_args(args)
    try:
        directory = parsed.directory
        absdir = os.path.realpath(directory)
        rest = parsed.cmd

        if not os.path.exists(directory):
            sys.exit(-2)

        di = get_dir_info(directory)

        if di.dirty:
            logger.error('The directory is dirty.',
                         directory=absdir, di=di, rest=" ".join(rest))
            sys.exit(1)

        else:
            # logger.info('This is not dirty.',
            #              directory=absdir, di=di, rest=" ".join(rest))
            if rest:
                res = subprocess.run(rest, cwd=directory)
                sys.exit(res.returncode)
            else:
                sys.exit(0)

    except SystemExit:
        raise
    except BaseException as e:
        logger.error(traceback.format_exc())
        sys.exit(3)

